==> Acme_BrainPhack-0.0.2.tgz: Acme_BrainPhack-0.0.2/Acme/BrainPhack/test/all_test.php <==
<?php
/*
 *   Copyright (c) 2010 msakamoto-sf <msakamoto-sf@users.sourceforge.net>
 *
 *   Licensed under the Apache License, Version 2.0 (the "License");
 *   you may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.*
 */

/**
 * @package Acme_BrainPhack
 * @author msakamoto-sf <msakamoto-sf@users.sourceforge.net>
 * @version $Id: all_test.php 1541 2010-01-19 15:16:24Z msakamoto-sf $
 */

require_once('simpletest/unit_tester.php');
require_once('simpletest/reporter.php');

$include_path = ini_get('include_path');
$__base_dir = realpath(dirname(__FILE__));
$__pear_src_dir = realpath($__base_dir.'/../');
ini_set('include_path', 
    $__base_dir.PATH_SEPARATOR.$__pear_src_dir.PATH_SEPARATOR.$include_path);

$test = &new TestSuite('All tests');
$test->addTestFile('MemoryStack_TestCase.php');
$test->addTestFile('Interpreter_TestCase.php');
$test->addTestFile('Translator_TestCase.php');
$test->run(new TextReporter());


/**
 * Local Variables:
 * mode: php
 * coding: iso-8859-1
 * tab-width: 4
 * c-basic-offset: 4
 * c-hanging-comment-ender-p: nil
 * indent-tabs-mode: nil
 * End:
 * vim: set expandtab tabstop=4 shiftwidth=4:
 */

==> Acme_BrainPhack-1.0.0.tgz: Acme_BrainPhack-1.0.0/Acme/BrainPhack/test/all_test.php <==
<?php
/*
 *   Copyright (c) 2010 msakamoto-sf <msakamoto-sf@users.sourceforge.net>
 *
 *   Licensed under the Apache License, Version 2.0 (the "License");
 *   you may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.*
 */

/**
 * @package Acme_BrainPhack
 * @author msakamoto-sf <msakamoto-sf@users.sourceforge.net>
 * @version $Id: all_test.php 1566 2010-01-23 00:17:08Z msakamoto-sf $
 */

require_once('simpletest/unit_tester.php');
require_once('simpletest/reporter.php');

$include_path = ini_get('include_path');
$__base_dir = realpath(dirname(__FILE__));
//$__pear_src_dir = realpath($__base_dir.'/../');
$__pear_src_dir = realpath($__base_dir.'/../../../'); // TODO
ini_set('include_path', 
    $__base_dir.PATH_SEPARATOR.$__pear_src_dir.PATH_SEPARATOR.$include_path);

$test = &new TestSuite('All tests');
$test->addTestFile('MemoryStack_TestCase.php');
$test->addTestFile('Interpreter_TestCase.php');
$test->addTestFile('Translator_TestCase.php');
$test->run(new TextReporter());


/**
 * Local Variables:
 * mode: php
 * coding: iso-8859-1
 * tab-width: 4
 * c-basic-offset: 4
 * c-hanging-comment-ender-p: nil
 * indent-tabs-mode: nil
 * End:
 * vim: set expandtab tabstop=4 shiftwidth=4:
 */
